<?php
namespace Teknisa\DF\Controllers;

use Teknisa\DF\Services\Ger06600TipoDeOperacaoService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class Ger06600TipoDeOperacaoController extends \Teknisa\DF\Controllers\TeknisaCrud {

    protected $dataSourceName = "tipooperac";
    protected $operacaoService;

    public function __construct($crudService, ParameterBag $parameterBag, Ger06600TipoDeOperacaoService $operacaoService) {
        $this->operacaoService = $operacaoService;
        parent::__construct($crudService, $parameterBag);
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            if(!empty($request->getFilterCriteria()->getConditions())){
                foreach ($request->getFilterCriteria()->getConditions() as $condition) {
                if ($condition['columnName'] === 'IDENTRSAIDOP') {
                        $idEntradaSaida = $condition['value'];
                    }
                }
                
                $this->operacaoService->validateDatabase($idEntradaSaida);
                parent::find($request, $response);
            }else{
                $response->addDataset(new DataSet('tipooperac', $array = array()));
            }
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function getParameters(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $parameters = $this->operacaoService->getParameters($request->getRow());
            $response->addDataSet(new DataSet("parameters", $parameters));
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $this->operacaoService->validateRowToSave($row);
            parent::save($request, $response);
            
            if ($row['__is_new']) {
                $response->addDataset(new DataSet('columnsToReturn', $this->crudService->getColumnsToReturn()[0]));
            }
        } catch (\Exception $e) {
            if(strpos($e->getMessage(), 'ORA-02292') !== false){
				$this->operacaoService->insereTipoCusto();
			}
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}
